Checksum

Trait Checksum 

pub trait Checksum {
    type Output: ChecksumOutput;

    // Required methods
    fn new() -> Self;
    fn update(&mut self, data: &[u8]);
    fn sum(self) -> Self::Output;

    // Provided method
    fn checksum(data: &[u8]) -> Self::Output
       where Self: Sized { ... }
}
A trait for computing checksums.

Types implementing this trait can compute a hash incrementally via update and sum, or in a single call via checksum.

Required Associated Types

type Output: ChecksumOutput

The type of the resulting checksum value.

Required Methods

fn new() -> Self

Create a new checksum instance with default settings (seed = 0, default secret for XXH3 variants).

fn update(&mut self, data: &[u8])

Feed additional data into the checksum.

fn sum(self) -> Self::Output

Finalize and return the computed checksum value.

Provided Methods

fn checksum(data: &[u8]) -> Self::Output
where Self: Sized,

Compute the checksum of data in a single call.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors